| GQPDB | R Documentation |
Quantile function and random generation for the
Generalized Quantile Parametrized (Bounded) distribution parametrized by three symmetrical
quantiles (q1, q2 and q3) and an alpha argument, representing the proportion of
density below the bottom quantile. All functions are vectorized.
qGQPDB(
p,
q1,
q2,
q3,
lower,
upper,
alpha = 0.1,
qf = stats::qnorm,
pf = stats::pnorm
)
rGQPDB(
N,
q1,
q2,
q3,
lower,
upper,
alpha = 0.1,
qf = stats::qnorm,
pf = stats::pnorm
)
p |
vector of probabilities |
q1, q2, q3 |
vectors of values, corresponding to lower, median and upper (symmetrical) quantiles |
lower, upper |
vectors of lower and upper bounds of distribution |
alpha |
vector of proportions of probability density under the lower bound (or above the upper bound, since the quantiles are symmetrical) |
qf |
quantile function |
pf |
distribution function |
N |
number of samples to draw |
The distribution is created by applying the inverse probit transform T(x)=Phi(x) to the Johnson SU distribution
vector of values
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.