| GQPDS | R Documentation |
Quantile function and random generation for the
Generalized Quantile Parametrized (Semibounded) distribution parametrized by three symmetrical
quantiles (q1, q2 and q3) and an alpha argument, representing the proportion of
density below the bottom quantile. All functions are vectorized.
qGQPDS(p, q1, q2, q3, lower = 0, alpha = 0.1, qf = stats::qnorm)
rGQPDS(N, q1, q2, q3, lower = 0, alpha = 0.1, qf = stats::qnorm)
p |
vector of probabilities |
q1, q2, q3 |
vectors of values, corresponding to lower, median and upper (symmetrical) quantiles |
lower |
vector of lower bounds of distribution |
alpha |
vector of proportions of probability density under the lower bound (or above the upper bound, since the quantiles are symmetrical) |
qf |
bare symmetrical unbounded standard quantile function |
N |
number of samples to draw from GQPDS |
The distribution is created by applying the exponential transform T(x)=exp(x) to the Johnson SU distribution
vector of values
qGQPDS(0.6, 20,50,90)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.