JQPDB: The J-QPD-B distribution

JQPDBR Documentation

The J-QPD-B distribution

Description

Density, distribution function, quantile function and random generation for the Johnson Quantile Parametrized (Bounded) distribution parametrized by three symmetrical quantiles (q1, q2 and q3) and an alpha argument, representing the proportion of density below the bottom quantile. All functions are vectorized.

Usage

qJQPDB(p, q1, q2, q3, lower, upper, alpha = 0.1)

pJQPDB(q, q1, q2, q3, lower, upper, alpha = 0.1)

dJQPDB(x, q1, q2, q3, lower, upper, alpha = 0.1)

rJQPDB(N, q1, q2, q3, lower = 0, upper = 1, alpha = 0.1)

Arguments

p

vector of probabilities

q1, q2, q3

vectors of values, corresponding to lower, median and upper (symmetrical) quantiles

lower, upper

vectors of lower and upper bounds of distribution

alpha

vector of proportions of probability density under the lower bound (or above the upper bound, since the quantiles are symmetrical)

x, q

vector of quantiles

N

number of samples to draw

Details

The distribution is created by applying the inverse probit transform T(x)=Phi(x) to the Johnson SU distribution

Value

vector of values

Examples

# should result in c(0,1,5,12,20)
qJQPDB(c(0, 0.05, 0.5, 0.95, 1), 1, 5, 12, 0, 20, alpha=0.05)
# should return c(0.00, 0.05, 0.50, 0.95, 1.00)
pJQPDB(c(0, 1, 5, 12, 20), 1,5,12, 0, 20, alpha=0.05)
# should return vector with first and last element equal to NaN
dJQPDB(c(0, 1, 5, 12, 20), 1,5,12, 0, 20, alpha=0.05)

dmi3kno/qpd documentation built on Sept. 29, 2024, 6:39 p.m.