| chen | R Documentation |
Defines quantile function (ICDF), and quantile density function as well as probability function (CDF) for Chen distribution
Distribution range is 0<x<\infty
Chen distribution QF, QDF, CDF and PDF are
Q(u)=\left[\ln\left(1-\frac{\ln(1-u)}{\lambda}\right)\right]^{1/\beta}
q(u)=\frac{\ln\left(1-\frac{\ln(1-u)}{\lambda}\right)^{\frac{1}{\beta}-1}}{\beta(\ln(1-u)-\lambda)(u-1)}
F(x)=1-\exp(\lambda(1-\exp(x^\beta)))
f(x)=\lambda\beta x^{\beta-1}\exp[\lambda(1-\exp(x^\beta)+x^\beta)]
qchen(p, lambda, beta)
fchen(x, lambda, beta, log = FALSE)
dqchen(p, lambda, beta, log = FALSE)
pchen(x, lambda, beta)
fchen(x, lambda, beta, log = FALSE)
rchen(n, lambda, beta)
p |
vector of probabilities |
lambda |
shape parameter of Chen distribution, must be positive |
beta |
shape parameter of Chen distribution, must be positive |
x |
numeric observations |
log |
logical; if TRUE, log density is returnes. Default is FALSE |
n |
numeric; number of samples to draw from Tukey Lambda distribution |
vector
Chen Z (2000) A new two-parameter lifetime distribution with bathtub shape or increasing failure rate function, Statistics & Probability Letters, Volume 49, Issue 2, https://doi.org/10.1016/S0167-7152(00)00044-4.
qchen(0.1, 0.5, 1)
p <- runif(1e4)
x <- qchen(p, 0.5, 1)+qchen(p, 1, 0.5)
hist(x,30)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.