| sechMyerson | R Documentation |
Density function for Hyperbolic Secant Myerson distribution (Myerson distribution with hyperbolic secant base function).
qsechMyerson(p, q1, q2, q3, alpha = 0.25, lower.tail = TRUE, log.p = FALSE)
fsechMyerson(
p,
q1,
q2,
q3,
alpha = 0.25,
log = FALSE,
lower.tail = TRUE,
log.p = FALSE
)
dqsechMyerson(
p,
q1,
q2,
q3,
alpha = 0.25,
log = FALSE,
lower.tail = TRUE,
log.p = FALSE
)
rsechMyerson(n, q1, q2, q3, alpha = 0.25)
psechMyerson(q, q1, q2, q3, alpha = 0.25, lower.tail = TRUE, log.p = FALSE)
dsechMyerson(x, q1, q2, q3, alpha = 0.25, log = FALSE)
p |
vector of probabilities |
q1, q2, q3 |
numeric values representing bottom quantile, middle quantile (50th percentile) and top quantile. Quantiles are assumed to be symmetrical. |
alpha |
numerical fixed proportion of distribution below the bottom quantile. Default value is 0.25 |
lower.tail |
logical; if TRUE (default), probabilities are |
log, log.p |
logical; if TRUE, probabilities p are given as log(p) |
n |
number of observations. If 'length(n)>1“, the length is taken to be the number required. |
x, q |
vector of quantiles. |
a vector of probabilities of length equal to length(x)
a vector of exceedance probabilities of length equal to length(x).
qsechMyerson(0.25, 10, 20, 40)
fsechMyerson(0.25, 10, 20, 40)
dqsechMyerson(0.25, 10, 20, 40)
rsechMyerson(1, 10, 20, 40)
psechMyerson(0.25, 10, 20, 40)
dsechMyerson(15, 10, 20, 40)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.