| JQPDS2 | R Documentation |
Density, distribution function, quantile function and random generation for the
Johnson Quantile Parametrized (Semibounded) Type II distribution parametrized by three symmetrical
quantiles (q1, q2 and q3) and an alpha argument, representing the proportion of
density below the bottom quantile. All functions are vectorized.
qJQPDS2(p, q1, q2, q3, lower = 0, alpha = 0.1)
pJQPDS2(q, q1, q2, q3, lower = 0, alpha = 0.1)
dJQPDS2(x, q1, q2, q3, lower = 0, alpha = 0.1)
rJQPDS2(N, q1, q2, q3, lower = 0, alpha = 0.1)
p |
vector of probabilities |
q1, q2, q3 |
vectors of values, corresponding to lower, median and upper (symmetrical) quantiles |
lower |
vector of lower bounds of distribution |
alpha |
vector of proportions of probability density under the lower bound (or above the upper bound, since the quantiles are symmetrical) |
q |
vector of quantiles |
x |
vector of observations |
N |
number of samples to draw |
The distribution is created by applying the exponential transform T(x)=exp(x) to the Johnson SU distribution
vector of values
qJQPDS2(0.6, 20,50,90)
pJQPDS2(15, 20,50,90)
# should return vector with first and last element equal to NaN
dJQPDS2(15, 20,50,90)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.